#
# spec file for package perl-YAML-PP
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-YAML-PP
Version:        0.010
Release:        1.1
%define cpan_name YAML-PP
Summary:        YAML 1.2 processor
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TI/TINITA/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.98
BuildRequires:  perl(Test::Warn)
%{perl_requires}

%description
This is Yet Another YAML Framework. For why this project was started, see
"WHY".

The parser aims to parse 'YAML 1.2'. See http://yaml.org/.

You can check out all current parse and load results from the
yaml-test-suite here: https://perlpunk.github.io/YAML-PP-p5/test-suite.html

* YAML::PP::Lexer

The Lexer is reading the YAML stream into tokens. This makes it possible to
generate syntax highlighted YAML output.

Note that the API to retrieve the tokens will change.

* YAML::PP::Parser

The Parser retrieves the tokens from the Lexer. The main YAML content is
then parsed with the Grammar.

* YAML::PP::Grammar

* YAML::PP::Constructor

The Constructor creates a data structure from the Parser events.

* YAML::PP::Loader

The Loader combines the constructor and parser.

* YAML::PP::Dumper

The Dumper will delegate to the Representer

* YAML::PP::Representer

The Representer will create Emitter events from the given data structure.

* YAML::PP::Emitter

The Emitter creates a YAML stream.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes etc examples README
%license LICENSE

%changelog
* Thu Nov  8 2018 coolo@suse.com
- updated to 0.010
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.010 2018-11-02 12:53:41+01:00
  - Fix regex for start of plain scalars
  - Large refactoring of lexer/parser.
  - Adjacent flow mapping values are now supported (JSON compat:
    `{"foo":23}`)
  - Empty flow mapping values are now supported
  - Fix nested flow collections
  0.009 2018-09-30 14:10:15+02:00
  - Fix yamlpp5-highlight bug from v0.008
  - load_file(), LoadFile(), dump_file() and DumpFile() can take filehandles
* Tue Sep 25 2018 coolo@suse.com
- updated to 0.008
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.008 2018-09-24 21:49:42+02:00
  - Support perl 5.8
  - Fix bug in folded block scalar parsing
  - Support multiple document end markers without content
  - Allow tabs at the beginning of line for flow nodes
  - Optimize reading input with many lines
  - Some internal changes
  - Refactor test suite
  - Add YAML::PP::Highlight::Dump()
* Thu Jun 21 2018 coolo@suse.com
- updated to 0.007
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.007 2018-06-20 21:36:26+02:00
  - Support .inf/.nan
  - Always output decimal point when dumping floats
  - YAML directive needs space
  - Improve emitter
  - Output multiline strings as literal block scalars
  - Fix regex for integers in Core Schema
  - Fix dumping of dualvars
  - Fix emitting of empty strings
  - Improve emitter scalar styles
  - Allow zero indented sequences for complex mapping keys/values
  - Fix parsing empty quoted strings
* Mon Apr  2 2018 coolo@suse.com
- updated to 0.006
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.006 2018-04-01 22:59:31+02:00
  - Support YAML Failsafe, JSON and Core Schema
  - Add dump_file, DumpFile
  - Add YAML::PP::Writer
  - Add YAML::PP::Representer
  - Detect cyclic references when loading
  - perl boolean false is now the empty string instead of 0
  - Add column numbers to error messages
  - Fixed various bugs in Emitter
  - Can now emit empty collections like [], {}
* Fri Nov 24 2017 coolo@suse.com
- updated to 0.005
  see /usr/share/doc/packages/perl-YAML-PP/Changes
  0.005 2017-11-23 17:09:55+01:00
  - Support reading files
  - Replace load() with load_string(), dump() with dump_string()
  - Support legacy interface functions Load, LoadFile, Dump
  - ... and --- are now correctly invalid in quoted scalars
  - Improve block scalar handling, passing two more tests
  - Improve multiline plain handling, passing another test
  - Partial implementation of flow style collections
  - Allow unicode in alias/anchor names
  - Document header at the end is now recognized
  - Support all valid escapes in double quotes
  - ...and forbid invalid ones
  - Multiline quoted strings must be indented
  - Forbid sequence or mapping as a mapping value on the same line
  - Forbit sequence after an anchor/tag on the same line
* Sun Oct  8 2017 coolo@suse.com
- initial package 0.004
  * created by cpanspec 1.78.08
